	
/*******************************************************************************
*   COLLAPSE AND RECOVERY							  							*
	How the COVID-19 Pandemic Eroded Human Capital and What to Do about It		*   
	MASTER DO-FILE                                                          	*
********************************************************************************
	
	PART 0:  User inputs
    PART 1:  Prepare folder paths
    PART 2:  Run selected code
	
	
    ** WRITTEN BY:   misaacsprieto@worldbank.org
    ** Last date modified: 22 Sept 2023
     
	** Stata Version: Stata 17.0 MP—Parallel Edition 

********************************************************************************
*   PART 0: USER INPUTS
*******************************************************************************/
	clear all

//  Set folder paths -----------------------------------------------------------
   
	gl root = "" 
	

	* Set common ado folder and version
	sysdir set PLUS "${root}/DataWork/ado"
	version 14.2



********************************************************************************
*   PART 1:  Prepare folder paths                                              *
********************************************************************************

	*Datawork
	global dw             "${root}/DataWork/"

	global ch1             "${root}/Chapter 1/"
	global ch2             "${root}/Chapter 2/"
	global ch3             "${root}/Chapter 3/"
	global ch4             "${root}/Chapter 4/"
	global ch5             "${root}/Chapter 5/"

	/* Subfolder Paths - COUNTRY DATA ------
	 These folders contain the first part of the analysis harmonizing aggregate
	 outcomes from the microdata of individual countries */
	 
	
	global country_list "Argentina Brazil Bulgaria Colombia Ethiopia  India Indonesia Jordan Mexico Morocco Pakistan Philippines SouthAfrica Turkiye Vietnam Uruguay Harmonized Other"
	
	foreach con in $country_list {
	    
    global dt_`con'			"${dw}\\`con'\\1 Data"
    global do_`con'   	"${dw}\\`con'\\2 Do"
    global out_`con'    	"${dw}\\`con'\\3 Out"
	
	}
	
	/* Subfolder Paths - CHAPTER OUTPUTS ------
	 These folders contain the first part of the analysis harmonizing aggregate
	 outcomes from the microdata of individual countries */
	
	forvalues i =1/5{
	    
	 * Data sets
    global dt_ch`i'			"${root}\\Chapter `i'\\1 Data"
    global do_ch`i'   	"${root}\\Chapter `i'\\2 Do"
    global out_ch`i'    	"${root}\\Chapter `i'\\3 Out"
	
	}
	

********************************************************************************
*   PART 2: Figures set up                                            			*
********************************************************************************

	graph set window fontface "Calibri Light"

	global cemerald "26 161 187"
	global cgreen "101 188 160"
	global cbeige "235 222 204"
	global cbrown "182 145 108"
	global corange "239 165 100"
	global cpink "248 203 202"
	global cred "236 110 109"
	set scheme white_tableau


********************************************************************************
*   PART 3: Run selected code                                                  *  
********************************************************************************

	set more off , perm
	global country_list  " Argentina Brazil Bulgaria Colombia Ethiopia India Indonesia  Jordan Mexico Morocco Pakistan Philippines SouthAfrica Turkiye Vietnam Uruguay Other"

	
	
	*---------------
	* CLEANING 
	*---------------
	
	/*
	foreach con in $country_list{
		
		
      /* Read only for  Confidential Data*/
	 if "`con'" != "Vietnam" & "`con'" != "India" & "`con'" != "Indonesia" & "`con'" != "Pakistan" & "`con'" != "Philippines" & "`con'" != "Ethiopia"  {
	 
	  do	"${do_`con'}//1_`con'_Cleaning.do"
	  
	 }
	
	
	/* Countries in chapter 2 and 3*/
	if "`con'" == "Argentina" | "`con'" == "Brazil"  |						/*
		*/ "`con'" == "Colombia"  | 										/*
		*/ "`con'" == "Ethiopia"  | "`con'" == "Indonesia"  |				/*
		*/ "`con'" == "Mexico" |											/*
		*/ "`con'" == "Pakistan"  | "`con'" == "SouthAfrica"  |				/*
		*/ "`con'" == "Uruguay" {
	 
	 	  do	"${do_`con'}//3_`con'_Enrollment_Indicators.do"
	 }

	 /* Countries in chapter 4*/
	 if "`con'" == "Brazil" | "`con'" == "Bulgaria"  | 						/*
		*/ "`con'" == "Ethiopia"  | 										/*
		*/ "`con'" == "India"  | "`con'" == "Jordan"  | 					/*
		*/ "`con'" == "Mexico" | 											/*
		*/ "`con'" == "Morocco"  | "`con'" == "Pakistan" | 					/*
		*/ "`con'" == "Philippines" | 										/*
		*/ "`con'" == "SouthAfrica"  | "`con'" == "Turkiye" |				/*
		*/ "`con'" == "Vietnam" {
	 
	 	 do	"${do_`con'}//2_`con'_Labor_Indicators.do"

	 }  
	
	}
	

	 /* Merging countries and applying */
	
	  do	"${do_Harmonized}//0_PredictedFunction.do"
	  do	"${do_Harmonized}//1_Create_merged_datasets.do"
	  do	"${do_Harmonized}//2_Apply_Methodology_Observed_vs_Predicted.do"
	*/
	
	*----------------------
	* PRODUCING FIGURES
	*----------------------
	
	
	/* Chapter 2 */


	  do 	"$do_ch2/Figure 2.3.do"
	  do	"$do_ch2/Figure 2.4.do"

	  do  	"$do_ch2/Ch2_Text numbers.do"	
	
	
	/* Chapter 3 */

	  do	"$do_ch3/Figure 3.1.do"
	  do 	"$do_ch3/Figure 3.2.do"
	  do  	"$do_ch3/Figure 3.3.do"
	  do 	"$do_ch3/Figure 3.4.do"
	  do	"$do_ch3/Figure 3.5.do"  
	  do 	"$do_ch3/Figure 3.6.do"
	  do 	"$do_ch3/Figure 3.7.do"
	  do	"$do_ch3/Figure 3.8.do"
	  /* READ ONLY data not shared
	  do 	"$do_ch3/Table A3.1.do"
	  */
	  do  	"$do_ch3/Figure B3.1.do"

	  do  	"$do_ch3/Ch3_Text_numbers.do"

	/* Chapter 4 */
	
	  do	"$do_ch4/Figure 4.1.do"
	  do	"$do_ch4/Figure 4.2.do"
	  do	"$do_ch4/Figure 4.3.do"
	  do	"$do_ch4/Figure 4.4.do"
	  do	"$do_ch4/Figure 4.5.do"
	  do	"$do_ch4/Figure 4.6.do"
	  do	"$do_ch4/Figure 4.7.do"
	  do	"$do_ch4/Figure 4.8.do"
	  do	"$do_ch4/Figure A4.1.1.do"
	  do	"$do_ch4/Figure B4.1.1.do"




	
