*---------------------------------------------------------------------
* Diego Parra
* PRIME AGE WORKERS: 2021 vs 2050 
* In text numbers calculations
*---------------------------------------------------------------------

* In text numbers Chapter 2: 

clear all 
set more off
cap log close

****************************************
********* Population estimates *********
****************************************

clear all 
import excel "${dt_ch2}/population_data.xlsx", ///
sheet("Estimates") cellrange(A17:DH20541) firstrow

ds Index Variant Regionsubregioncountryorar Notes Locationcode ///
ISO3Alphacode ISO2Alphacode SDMXcode Type Parentcode Year, not 

foreach v of var `r(varlist)' { 
   local x : variable label `v'
   rename `v' a_`x'
   destring a_`x', replace force
}

save "${dt_ch2}/estimates_data.dta", replace

***********************************
********* Historical data *********
***********************************

clear all
import excel "${dt_ch2}\population_data.xlsx", ///
sheet("Medium variant") cellrange(A17:DH22536) firstrow

ds Index Variant Regionsubregioncountryorar Notes Locationcode ///
ISO3Alphacode ISO2Alphacode SDMXcode Type Parentcode Year, not 

foreach v of var `r(varlist)' { 
   local x : variable label `v'
   rename `v' a_`x'
   destring a_`x', replace force
}

save "${dt_ch2}\historic_data.dta", replace

********************************************************
********* Append historical and estimates data *********
********************************************************

use "${dt_ch2}\estimates_data.dta", clear
append using "${dt_ch2}\historic_data.dta"

drop Index Notes Locationcode SDMXcode Parentcode

rename Regionsubregioncountryorar country
rename ISO3Alphacode ISO2
rename ISO2Alphacode ISO3 

sort country Year

**** Calculate population groups 
gen pop_0_5 = (a_0 + a_1 + a_2 + a_3 + a_4 + a_5)
gen pop_0_6 = (a_0 + a_1 + a_2 + a_3 + a_4 + a_5 + a_6)
gen pop_0_7 = (a_0 + a_1 + a_2 + a_3 + a_4 + a_5 + a_6 + a_7)

gen pop_0_24 = (a_0 + a_1 + a_2 + a_3 + a_4 + a_5 + a_6 + a_7 + ///
a_8 + a_9 + a_10 + a_11 + a_12 + a_13 + a_14 + a_15 + ///
a_16 + a_17 + a_18 + a_19 + a_20 + a_21 + a_22 + a_23 + a_24)

gen pop_0_25 = (a_0 + a_1 + a_2 + a_3 + a_4 + a_5 + a_6 + a_7 + ///
a_8 + a_9 + a_10 + a_11 + a_12 + a_13 + a_14 + a_15 + ///
a_16 + a_17 + a_18 + a_19 + a_20 + a_21 + a_22 + a_23 + a_24 + a_25)

gen pop_25_54 = (a_25 + a_26 + a_27 + a_28 + a_29 ///
+ a_30 + a_31 + a_32 + a_33 + a_34 + a_35 + a_36 + a_37 + a_38 + a_39 ///
+ a_40 + a_41 + a_42 + a_43 + a_44 + a_45 + a_46 + a_47 + a_48 + a_49 ///
+ a_50 + a_51 + a_52 + a_53 + a_54)

*** Full table by income group
*br country Year pop_0_24 pop_0_25 pop_25_54 if Type == "Income Group" ///
& (Year == 2021 | Year == 2050)

*--------
* pg 30 
*--------

/* This report is the first comprehensive analysis of what happened to 
human capital during the pandemic. It focuses on individuals who were 
25 years or younger at the outset of the pandemic. These cohorts will 
make up 90 percent of prime-age adults in 2050 */

*25 years or younger at the outset of the pandemic: 3239281
tabstat pop_0_24 if country == "WORLD" & Year == 2021, st(mean n)

*Prime-age adults in 2050: 3721785
tabstat pop_25_54 if country == "WORLD" & Year == 2050, st(mean n)

*Percentage: 3239281/3721785 = 87%

/* In 2050, at least 20–25 percent of the prime-age workforce would 
have been in the womb or under age 6 during the lockdowns associated 
with the COVID-19 pandemic */

*In the womb or under age 6 during the lockdowns: 953237
tabstat pop_0_6 if country == "WORLD" & Year == 2020, st(mean n)

*Prime-age adults in 2050: 3721785
tabstat pop_25_54 if country == "WORLD" & Year == 2050, st(mean n)

*Percentage: 953237/3721785 = 26%

/* Compared with what would have been predicted from pre-pandemic trends, 
observed enrollment at the end of 2021 was down by more than 15 percentage 
points in Pakistan, 13 percentage points in Brazil, 10 percentage
points in South Africa, and 8 percentage points in Indonesia. */

use "${dt_ch2}/Enrollment Predictions.dta", replace 

gen open = .
replace open = 1  if country== "Pakistan" &  (dateq == yq(2021,1)  | dateq >= yq(2022,1) )
replace open = 1  if country== "SouthAfrica" &  dateq >= yq(2020,4) 
replace open = 1  if country== "Brazil" &  dateq >= yq(2021,2) 

tabstat pp_d_enroll_5 if open == 1 & country== "Pakistan"    // 15 pp
tabstat pp_d_enroll_5 if open == 1 & country== "Brazil"      // 13 pp
tabstat pp_d_enroll_5 if open == 1 & country== "SouthAfrica" // 10 pp




























