*---------------------------------------------------------------------
* Margarita Isaacs
* Chapter 3 
* In text numbers calculations
*---------------------------------------------------------------------

* In text numbers Chapter 3: 

*--------
* pg 61
*--------

use "${dt_ch3}/Data_School_Closures.dta", replace 


/*Latin America and the Caribbean and South Asia, children lost 1.7 years.*/


// Average Closed weeks
tabstat full_partial_weeks if WBRegion == "LAC" | WBRegion == "SA" ,
// Number of days discounted from the 55 weeks of the year 
tabstat AcademicBreak if WBRegion == "LAC" | WBRegion == "SA" , 
display 52 - (142/7)
// Lost years of schooling in LAC and SA
display 52 /31

/*However, in Ethiopia and Pakistan, two lower-income countries with data 
available before and after school closures, enrollment fell by 4 percentage 
points and 6 percentage points, respectively, and 7.6 million children dropped 
out of school in Pakistan alone.
*/
	use "${dt_ch3}/Enrollment Predictions.dta", replace 
gen open = .
replace open = 1 if country== "Ethiopia" &  year == 2021 
replace open = 1  if country== "Pakistan" &  (dateq == yq(2021,1)  | dateq >= yq(2022,1) )

tabstat pp_d_enroll_6_14 if (country == "Ethiopia" | country == "Pakistan" ) & open ==1, by(country)
	
	
*--------
* pg 62 
*--------

/*In March 2020, when the pandemic first hit, schools closed in 180 countries. 
One year later, in March 2021, schools were still partially or fully closed 
in 94 countries, with more than 1 billion students affected
*/

use "${dt_ch3}/Data_School_Closures.dta", replace 

//Children affected by school closures
tabstat sum_pop_5_14 if full_close>=0 & income_type<=3 , s(sum) format(%12.0fc)
gen sum = FullyClosed + PartiallyOpen +AcademicBreak 
gen country_count = 1 
tabstat country_count if sum>= 356  , s(sum)

*--------
* pg 63 
*--------
/* For example, between March 2020 and March 2022 schools were closed for 75 days in Tanzania but 529 days in Uganda;
178 days in Morocco but 391 days in Saudi Arabia; and 169 days in Vietnam but 510 days in the Philippines*/
gen days = full_partial_weeks*7
tabstat days if Country == "Tanzania" | Country == "Uganda" | Country == "Morocco" | Country == "Saudi Arabia" | Country == "Vietnam" | Country == "Philippines", by(Country)


*--------
* Pg 66 
*--------

/*Setting aside Ethiopia and Pakistan, after schools reopened the biggest drops in enrollment for children ages 6–14 were 1.3 percentage points in Colombia and 1.0 percentage point in Brazil and Mexico.*/

use "${dt_ch3}/Enrollment Predictions.dta", replace 

keep if (country== "Ethiopia" | country== "Pakistan" | country== "Indonesia" | country== "SouthAfrica"  | country== "Colombia" | country== "Brazil"| country== "Mexico" | country== "Argentina" | country== "Uruguay" )  

* School closures indicator based on UNESCO data
gen open = .
replace open = 1 if country== "Ethiopia" &  year == 2021 
replace open = 1  if country== "Pakistan" &  (dateq == yq(2021,1)  | dateq >= yq(2022,1) )
replace open = 1  if country== "Indonesia" &  dateq >= yq(2020,4) 
replace open = 1  if country== "SouthAfrica" &  dateq >= yq(2020,4) 
replace open = 1  if country== "Colombia" &  dateq >= yq(2021,1) 
replace open = 1  if country== "Brazil" &  dateq >= yq(2021,2) 
replace open = 1  if country== "Mexico" &  dateq >= yq(2021,4) 
replace open = 1  if country== "Argentina" &  dateq >= yq(2020,4) 
replace open = 1  if country== "Uruguay" &  dateq >= yq(2020,2) 

tabstat pp_d_enroll_6_14 if (country != "Ethiopia" & country != "Pakistan" ) & open ==1, by(country)
/*
In Pakistan, school enrollment declined by 6.0 percentage points overall 
(6.7 percentage points at the primary level and 4.6 percentage points at 
the lower-secondary level). This relatively large decline is corroborated by 
additional one-off studies. Similarly, in Ethiopia, the only low-income country 
in the sample, enrollment fell by 4.0 percentage points for children ages 6–14 
(4.6 percentage points at the primary level and 4.0 percentage points at the 
lower-secondary level)
*/
tabstat pp_d_enroll_6_14 if ( country == "Pakistan"  ) & open ==1, by(country)
tabstat pp_d_enroll_6_11  pp_d_enroll_12_14 if ( country == "Pakistan" ) & open ==1, by(country)


*--------
* Pg 69 
*--------

use "${dt_ch3}/Data_Learning_Losses_lit.dta", replace 


/*
Overall, for every 30 days of school closures, students lost, on average, about 
34 days of learning. Across all these studies, the mean learning loss is 
6.2 months, while the average length of school closures is 5.9 months

*/
	reg learninglossmonths schoolclosuremonths if inlist(credibility_rank,1), nocons
	local _beta = string(round(_b[schoolclosuremonths],0.01))
	display 30 * `_beta'
	
	tabstat learninglossmonths schoolclosuremonths 
/*Across this subsample of studies, the average learning loss is 7.9 months,
 while the average school closure is 6.6 months.*/
 
	tabstat learninglossmonths schoolclosuremonths  if inlist(credibility_rank,1)

*--------
* Pg 71
*--------

/*Dropouts account for 23 percent of lost LAYS in low-income countries, compared
 with 3 percent in upper-middle-income countries. Second, lost LAYS are much 
 higher in regions with longer school closures and better quality of schooling*/
 
 /* Read only // data not shared - Read only
	use "$dt_Other/Raw/prepandemic LAYS update 15122022.dta" , replace /*Not shared*/

	tabstat ll_do_tot , by(wbincomegroup)
	
/*Bulgaria and Mozambique both lost around 0.46 LAYS. However, in Mozambique 30 percent of lost LAYS stemmed from dropouts, whereas in Bulgaria all the lost LAYS were from learning losses. Moreover, in Bulgaria the lost LAYS were relatively smaller (equivalent to 5.5 percent of its total pre-pandemic LAYS) than in Mozambique (where losses amounted to 10.6 percent of its total pre-pandemic LAYS). • In China and Madagascar, schools were closed for about the same amount of time. In both cases, they translated into 0.31 lost LAYS. However, in Madagascar more than one-third of these lost LAYS were from
dropouts, whereas in China nearly all the lost LAYS were from learning losses.
*/
	tabstat ll_h2_tot ll_do_tot ll_nd_tot dlays if wbcountryname == "Mozambique" | wbcountryname =="Bulgaria", by(wbcountryname)

*/
