	
/*******************************************************************************
*	Figure 3.4: For 30 days of school closures, students lost 34 days of learning
*   School closure versus learning loss, by country
* Margarita Isaacs 
*******************************************************************************/
use "${dt_ch3}/Data_Learning_Losses_lit.dta", replace 

* Generate country labels

	gen mlabpos = 4
	replace mlabpos = 11 if country == "South Africa (Ardington et al. 2021)"
	replace mlabpos = 12 if country == "Belgium (Gambi et al. 2021)"
	replace mlabpos = 9  if country == "Germany (Ludewig et al. 2022)"
	replace mlabpos = 11 if country == "Ethiopia (Araya et al. 2021)"
	replace mlabpos = 9  if country == "Italy (Contini et al. 2021)"
	replace mlabpos = 3  if country == "United Kingdom (Rose et al. 2021)"
	replace mlabpos = 6  if country == "Netherlands (Haelermans et al. 2022)"
	replace mlabpos = 12 if country == "Spain (Arenas et al. 2022)"

	replace mlabpos = 11 if country == "Australia (Gore et al. 2021)"
	replace mlabpos = 11 if country == "Switzerland (Tomasik et al. 2020)"
	replace mlabpos = 3  if country == "Denmark (Birkelund et al. 2021)"
	replace mlabpos = 12 if country == "Canada (Georgiou et al. 2021)"
	replace mlabpos = 6  if country == "USA (Kuhfeld et al. 2022)"
	
* Estimation of lerning months to school closures
	reg learninglossmonths schoolclosuremonths, nocons
	sum learninglossmonths
	local llm=string(round(`r(mean)',0.1))
	sum learninglossmonths if income_group==1
	local llm1=string(round(`r(mean)',0.1))
	sum learninglossmonths if income_group==2
	local llm2=string(round(`r(mean)',0.1))
	sum learninglossmonths if income_group==3
	local llm3=string(round(`r(mean)',0.1))
		
	sum schoolclosuremonths 
	local scm=string(round(`r(mean)',0.1))
	sum schoolclosuremonths if income_group==1
	local scm1=string(round(`r(mean)',0.1))
	sum schoolclosuremonths if income_group==2
	local scm2=string(round(`r(mean)',0.1))
	sum schoolclosuremonths if income_group==3
	local scm3=string(round(`r(mean)',0.1))
	
		
	tw /*
	*/	(scatter learninglossmonths schoolclosuremonths if income_group==1, 	/*
	*/ 			mlabel(countryid) mlabsize(*1.1) mlabv(mlabpos) 				/*
	*/			mlabcolor("101 188 160") mcolor( "101 188 160" ) mlabgap(*.5)) 	/*
	*/	(scatter learninglossmonths schoolclosuremonths if income_group==2,		/*
	*/			 mlabel(countryid) mlabsize(*1.1) mlabv(mlabpos) 				/*
	*/			 mlabcolor("239 165 100") mcolor("239 165 100" )) 				/*
	*/	(scatter learninglossmonths schoolclosuremonths if income_group==3, 	/*
	*/			mlabel(countryid) mlabsize(*1.1) mlabv(mlabpos) 				/*
	*/			mlabcolor("236 110 109") mcolor("236 110 109" ) mlabgap(*.5)) 	/*
	*/	(function y=x, range(0 20) lpattern(-) lwidth(thin) lcolor(black))		/*
	*/			, title("School closure vs Learning loss", size(medium)) 		/*
	*/			xtitle("School closure (in months)", size(medium)) 				/*
	*/			ytitle("Learning Loss (in months)", size(medium)) 				/*
	*/			text(22 22 "Learning loss"" = ""Months of school closure", 		/*
	*/			placement(c) angle(90) size(small) )							/*
	*/			legend(order(1 "High-income" 2 "Upper-middle-income" 3 "Low- and lower-middle-income" ) /*
	*/			pos(6) row(2) size(*1.01) lcolor(white)) 						/*
	*/			note("Mean learning loss = `llm' months" "Mean school closure = `scm' months") /*
	*/			xsize(4) ysize(4.5) ylab(0(5)25, labsize(*1.01) nogrid) xlab(0(5)25, labsize(*1.01) nogrid)
				

		graph export "${out_ch3}/Ch3_Fig3_4Learning_Loss_v_School_Closures.wmf", replace 


