/*******************************************************************************
*   Collapse and Recovery: 							   						   *
	How the COVID-19 Pandemic Eroded Human Capital and What to Do about it 	   *
*   CHAPTER 3   
********************************************************************************

/*******************************************************************************
*	Figure 3.5: Learning losses were higher in countries with lower GDP per 
	capita after controlling for length of school closures
	Ratio of learning loss to school closure versus GDP per capita, by country
*******************************************************************************/
				

********************************************************************************
	Prepare data
*******************************************************************************/


	* Load data
	use  "${dt_ch3}/Data_Learning_Losses_lit.dta", replace 


	* Generate country labels
	gen CountryID = countryid	
	replace CountryID = "GBR" if CountryID == "UK"
	replace CountryID = "MWI" if CountryID == "MAL"
	replace CountryID = "DEU" if CountryID == "GER"

	merge 1:1 CountryID using "$dt_Other/Raw/gdp.dta", nogen keep(master match)

	
	* Estimating learning loss months  to school closure ratio
	gen ratiols = learninglossmonths/ schoolclosuremonths

	reg ratiols schoolclosuremonths, robust
	predict resid_ratio_closure, residuals

	reg ratiols log_gdp19, robust
	predict resid_ratio_gdp, residuals

	* Regression against GDP
	reg ratiols log_gdp19
	predict cooksd if e(sample), cooksd
	ta country if cooksd > (4/_N)
		

	reg ratiols log_gdp19 if cooksd < =(4/_N), robust		
	reg ratiols log_gdp19 if credibility_rank==1 & countryid!="MAL", robust


	gen mlabpos = 3	
	replace mlabpos = 11 if inlist(countryid,"AUS")
	replace mlabpos = 1 if inlist(countryid,"DNK")
	replace mlabpos = 5 if inlist(countryid,"CZE","NLD")



	tw /*
	*/ (scatter ratiols log_gdp19 if income_group==1 & cooksd < (4/_N), /*
	*/ 		mlabel(countryid) mlabsize(*1) mlabvp(mlabpos)  /*
	*/ 		mlabcolor("101 188 160") mcolor("101 188 160") mlabgap(*.5)) /*
	*/ (scatter ratiols log_gdp19 if income_group==2 & cooksd < (4/_N), /*
	*/      mlabel(countryid) mlabsize(*1) mlabvp(mlabpos) /*
	*/ 		mlabcolor("239 165 100") mcolor("239 165 100")) /*
	*/ (scatter ratiols log_gdp19 if income_group==3 & cooksd < (4/_N), /*
	*/ 		mlabel(countryid) mlabsize(*1) mlabvp(mlabpos) /*
	*/ 		mlabcolor("236 110 109") mcolor("236 110 109") mlabgap(*.5)) /*
	*/ (lfit ratiols log_gdp19 if income_group!=4 & cooksd < (4/_N), /*
	*/  	lpattern(dash) lcolor("235 222 204") range(7.5 11.5)) 	/*
	*/ 		, xtitle("Log GDP per capita (2019)", size(medium)) ///
			ytitle("Ratio of learning loss to school closure", size(medium)) /*
	*/ 		legend(order(1 "High-income" 2 "Upper-middle-income" 3 "Low- and lower-middle-income" 4 "Regression line") /*
	*/ 		pos(6) row(2) size(*1.2))  bgcolor(white) /*
	*/      xsize(6) ysize(4.5) ylab(0(.5)2.5, labsize(*1.2) nogrid) xlab(7(1)12, labsize(*1.2) nogrid)
			 
		graph export "${out_ch3}/Ch3_Fig_3_5_Ratio_v_GDP.wmf", replace 	


