********************************************************************************
* By: Ritika DSouza
*  Figure 3.6
*******************************************************************************

* Load data
use "$dt_Other/Raw/Lost LAYS for rep.dta", replace /*Not shared*/

* Drop observations where wbincomegroup is "High income"
drop if wbincomegroup == "High income"

* Calculate the mean of various variables by wbregion, weighted by population
collapse (mean) ll_h2_tot ll_nd_tot ll_do_tot qeyrs_mf_2020 dlays [aw=population], by(wbregion)

* Create a new variable wbr to represent wbregion numerically
gen wbr = .
replace wbr = 1 if wbregion == "South Asia"
replace wbr = 2 if wbregion == "Latin America & Caribbean"
replace wbr = 3 if wbregion == "Middle East & North Africa"
replace wbr = 4 if wbregion == "East Asia & Pacific"
replace wbr = 5 if wbregion == "Sub-Saharan Africa"
replace wbr = 6 if wbregion == "Europe & Central Asia"

* Fill missing values in wbr with 7
insobs 1
replace wbr = 7 if wbr == .

* Label the values of wbr variable for better readability
label define reg 1 "SA" 2 "LAC" 3 "MENA" 4 "EAP" 5 "SSA" 6 "ECA" 7 "Global average", modify
label values wbr reg

* Calculate the mean of ll_h2_tot, ll_nd_tot, and ll_do_tot
foreach v in ll_h2_tot ll_nd_tot ll_do_tot {
    egen m_`v' = mean(`v')
    replace `v' = m_`v' if `v' == .
    drop m_`v'
}

* Create a twoway graph
tw    (bar ll_h2_tot wbr, barw(.7)) 										/*
	*/    (bar ll_nd_tot wbr, barw(.7)) 									/*
	*/    (scatter ll_h2_tot wbr, msymbol(none) mlabel(ll_h2_tot) 			/*
	*/      mlabpos(6) mlabcolor(black)) 				/*
	*/    , graphregion(color(white)) 										/*
	*/    xtitle("") xlabel(1(1)7, valuelabel labsize(small)) 				/*
	*/    ytitle("LAYS lost from pandemic (years)") ylabel(0(-.2)-1, labsize(small)) /*
	*/    legend(order(2 "LAYS lost from learning losses" 1 "LAYS lost from dropouts") /*
	*/    size(small) region(lstyle(none)))
	
gr export "${out_ch3}/Ch3_Fig3_6.wmf", replace
