/*******************************************************************************
*   Collapse and Recovery: 							   						   *
	How the COVID-19 Pandemic Eroded Human Capital and What to Do about it 	   *
*   CHAPTER 3   
********************************************************************************


	REQUIRES:	"$data1/prepandemic LAYS update 15122022.dta"
	CREATES:	${output}/Ch3_Fig3_7_LAYS_lost_vs_LAYSBase.wmf
				

********************************************************************************
	Prepare data
*******************************************************************************/

	* Load data 
	use "$dt_Other/Raw/Lost LAYS for rep.dta", replace /*anonymized*/

 

	gen lost_lays= ll_h2_tot*-1 // Total lost LAYS
	gen p_lost_lays= dlays*-1 // Share of Lost LAYS
	gen lays_hci2020 = qeyrs_mf_2020 // LAYS according to HCI 2020


	gen label= ""

	* Selected countries
	gen label3= ""
	//replace label3= wbcountryname if inlist(wbcode,"CHN","MYS","MEX" , "LBN", "EGY" ,"HND") // For unanomized dataset only

/*******************************************************************************
*	Figure 3.7: Countries that had similar Learning-Adjusted Years of Schooling 
	(LAYS) before the pandemic had vastly different experiences with learning losses
	Total LAYS lost from the pandemic versus pre-pandemic LAYS, by country and region
*******************************************************************************/

	tw /*
	*/ 	(scatter lost_lays lays_hci2020  if wbregion == "East Asia & Pacific", 		/*
	*/ 				mlwidth(*1.7) msymbol(O) mcolor("26 161 187" )) 			/*
	*/ 	(scatter lost_lays lays_hci2020  if wbregion == "Europe & Central Asia", 		/*
	*/ 				mlwidth(*1.7) msymbol(O) mcolor( "101 188 160")) 			/*
	*/ 	(scatter lost_lays lays_hci2020  if wbregion == "Latin America & Caribbean", 	/*
	*/ 				mlwidth(*1.7) msymbol(O) mcolor("239 165 100")) 			/*
	*/ 	(scatter lost_lays lays_hci2020  if wbregion == "Middle East & North Africa", 	/*
	*/ 				mlwidth(*1.7) msymbol(O) mcolor("236 110 109")) 			/*
	*/ 	(scatter lost_lays lays_hci2020  if wbregion == "South Asia", 					/*
	*/ 				mlwidth(*1.7) msymbol(O) mcolor("248 203 202")) 			/*
	*/ 	(scatter lost_lays lays_hci2020  if wbregion == "Sub-Saharan Africa", 			/*
	*/ 				mlwidth(*1.7) msymbol(O) mcolor("115 49 39")) 				/*
	*/ 	(scatter lost_lays lays_hci2020  if label3!="" , 								/*
	*/ 				msymbol(Oh) mcolor(black) mlabcolor(black) /* mlabel(wbcountryname) 	
	*/ 				mlabposition(3) mlabsize(*1.3) mlwidth(*1) mlabgap(*.5)) 	/*
	*/ 	(lfit lost_lays lays_hci2020 , lcolor("236 110 109") lpattern(dash)) 			/*
	*/ 	if wbincomegroup!="High income"											/*
	*/  		, xlab(,  labsize(*1.2) nogrid  labcolor("202 182 163")) 		/*
	*/ 	 	ylab( , labsize(*1.2) nogrid labcolor("202 182 163"))				/*
	*/ 		legend(order(1 "East Asia and Pacific" 2 "Europe and Central Asia" 	/*
	*/  3 "Latin America and the Caribbean" 4 "Middle East and North Africa" 	/*
	*/  5  "South Asia" 6 "Sub-Saharan Africa" ) 								/*
	*/ 		region(lcolor(none)) rows(2) pos(6) size(small)) 					/*
	*/ 		xscale(lcolor("202 182 163") lwidth(*1.2) )							/*
	*/ 		yscale(lcolor("202 182 163") lwidth(*1.2) ) 						/*
	*/ 		xtitle("Pre-pandemic LAYS", size(medium) color("202 182 163")) 		/*
	*/ 	 	ytitle("Total LAYS lost due to pandemic (years)", /*
	*/ 	 	size(medium) color("202 182 163") )	xsize(7) ysize(5) 
		

	graph export "${out_ch3}/Ch3_Fig3_7_LAYS_lost_vs_LAYSBase.wmf", replace 


	
