/*******************************************************************************
*   Collapse and Recovery: 							   						   *
	How the COVID-19 Pandemic Eroded Human Capital and What to Do about it 	   *
*   CHAPTER 3   
********************************************************************************


	REQUIRES:	"$data1/prepandemic LAYS update 15122022.dta"
	CREATES:	${output}/Ch3_Fig3_8_LAYS_lost_vs_LAYSShare.wmf
				

********************************************************************************
	Prepare data
*******************************************************************************/

	* Load data 
	use "$dt_Other/Raw/Lost LAYS for rep.dta", replace /*anonymized*/

 

	gen lost_lays= ll_h2_tot*-1 // Total lost LAYS
	gen p_lost_lays= dlays*-1 // Share of Lost LAYS
	gen lays_hci2020 = qeyrs_mf_2020 // LAYS according to HCI 2020






/*******************************************************************************
*	Figure 3.8: Countries not losing many total Learning-Adjusted Years 
	of Schooling (LAYS) may have lost much in terms of pre-pandemic shares 
	of LAYS (and vice versa)
	Share of pre-pandemic LAYS lost versus total LAYS lost from the
	pandemic, by country and region
*******************************************************************************/



	* Selected countries

gen lab2 = ""
//replace lab2= wbcountryname if inlist(wbcode,"CHN","SSD","IRQ","SRB")
//replace lab2= wbcountryname if inlist(wbcode,"BGR","ECU",  "UGA" )
//replace lab2= wbcountryname if inlist(wbcode,"MLI","ECU", "HND", "PAK")


 
twoway 	(scatter p_lost_lays lost_lays  if wbregion == "East Asia & Pacific", 				/*
	*/  	mlwidth(*1.5) msymbol(O) mcolor("26 161 187")) 					/*
	*/ 	(scatter p_lost_lays lost_lays  if wbregion == "Europe & Central Asia", 				/*
	*/ 		mlwidth(*1.5) msymbol(O) mcolor( "101 188 160")) 				/*
	*/ 	(scatter p_lost_lays lost_lays  if wbregion == "Latin America & Caribbean", 			/*
	*/ 		mlwidth(*1.5) msymbol(O) mcolor("239 165 100")) 				/*
	*/ 	(scatter p_lost_lays lost_lays  if wbregion == "Middle East & North Africa", 			/*
	*/ 		mlwidth(*1.5) msymbol(O) mcolor("236 110 109")) 				/*
	*/ 	(scatter p_lost_lays lost_lays  if wbregion == "South Asia", 							/*
	*/ 		mlwidth(*1.5) msymbol(O) mcolor("248 203 202")) 				/*
	*/ 	(scatter p_lost_lays lost_lays  if wbregion == "Sub-Saharan Africa", 					/*
	*/ 		mlwidth(*1.5) msymbol(O) mcolor("115 49 39")) 					/*
	*/ 		(scatter p_lost_lays lost_lays  if lab2!="" , 									/*
	*/ 	msymbol(Oh) mcolor(black) mlabcolor(black) /* mlabel(wbcountryname) 
	*/ 	mlabposition(3) mlabsize(*1.3) mlwidth(*1) mlabgap(*.5)) 			/*
	*/ 	(lfit p_lost_lays lost_lays , lcolor(cranberry) lpattern(dash))						/*
	*/ 	if wbincomegroup!="High income", 									/*
	*/ xlab(, nogrid labcolor("202 182 163")) 								/*
	*/ ylab( ,nogrid labcolor("202 182 163"))								/*
	*/ plotregion(lcolor(none)) 											/*
	*/ legend(order(1 "East Asia and Pacific" 2 "Europe and Central Asia"	/*
	*/  3 "Latin America and the Caribbean" 4 "Middle East and North Africa" /*
	*/  5  "South Asia" 6 "Sub-Saharan Africa" ) 							/*
	*/ 	region(lcolor(none)) rows(2) pos(6) size(small)) 					/*
	*/ 	xscale(lcolor("202 182 163") lwidth(*1.2) )							/*
	*/  yscale(lcolor("202 182 163") lwidth(*1.2) ) 						/*
	*/ 	xtitle("Total LAYS lost from pandemic", size(medium) 				/*
	*/ color("202 182 163") ) 												/*
	*/ ytitle("Share of pre-pandemic LAYS lost (%)", size(medium)			/*
	*/  color("202 182 163") ) xsize(7) ysize(5) xlab(, labsize(*1.5))	/*
	*/  ylab(,labsize(*1.5))
  	
	

graph export "${out_ch3}/Ch3_Fig3_8_LAYS_lost_vs_LAYSShare.wmf", replace 
	
