/*******************************************************************************
*   Collapse and Recovery: 							   						   *
	How the COVID-19 Pandemic Eroded Human Capital and What to Do about it 	   *
*   CHAPTER 3   
********************************************************************************


	REQUIRES:	"$data/closures_time"
				"$data/regiones.dta"
				"$wb_govn/wgidataset"
				 "$data/gdp.dta"
	CREATES:	${output}/Ch3_Fig3Box_1PanelA_GDPpercapita_v_School_Closures.wmf
				"${output}/Ch3_Fig3Box_1PanelB_GovEffectiveness_v_School_Closures.wmf"
				

********************************************************************************
	Prepare data
*******************************************************************************/

	* Load data 
	use "$dt_Other/Raw/wgidataset",  clear
	
	rename *, lower
	tab year
	keep if year >=2014 & year<=2019
	rename countryname country 

	collapse (mean) gee , by(country code)

	kountry code, from(iso3c)
	tab NAMES_STD
	
	* Merge auxiliary datasets 
	merge 1:1 NAMES_STD using "$dt_Other/Raw/closures_time.dta"
	tab NAMES_STD if _merge == 1
	tab NAMES_STD if _merge == 2
	keep if _merge == 3
	drop _merge

	merge 1:1 NAMES_STD using "$dt_Other/Raw/regiones.dta"
	tab NAMES_STD if _merge == 1
	tab NAMES_STD if _merge == 2
	keep if _merge == 3
	drop _merge


	merge 1:1 NAMES_STD using  "$dt_Other/Raw/gdp.dta"
	drop if _merge == 2
	drop _merge  

		


	encode Geographicalregion, gen(region)



	label var gee "Goverment Effectiveness (2014-2019)"
	label var log_gdp19 "GDP per capita 2019 (logs)"
	label var weeksfullyclosed "Length of full school closures (weeks)"
	label var region "Region"
		
		
/*******************************************************************************
*	Figure BOX 3.2.1: There is no systematic relationship between the length of 
	school closures and log GDP per capita and an indicator of governance effectiveness
*******************************************************************************/

	gen marker =1 if country == "Colombia" | country == "Mexico" |				/*
	*/ country == "Poland"  | country == "Slovak Republic" | 					/*
	*/ country == "Egypt, Arab Rep." |  country == "Lebanon"  | 				/*
	*/ country == "Bangladesh" |  country == "Pakistan" | 						/*
	*/ country == "Uganda" |  country == "Bangladesh"  | 						/*
	*/ country == "Ethiopia" 


	tw /*
	*/ (scatter weeksfullyclosed  gee  if Geographicalregion == "East Asia and Pacific", 	/*
	*/ 				mlwidth(*1.5) msymbol(O) mcolor("26 161 187")) 							/*
	*/ (scatter weeksfullyclosed  gee  if Geographicalregion == "Europe and Central Asia", 	/*
	*/				mlwidth(*1.5) msymbol(O) mcolor("101 188 160")) 						/*
	*/ (scatter weeksfullyclosed  gee  if Geographicalregion == "Latin America and the Caribbean", 	/*
	*/ 				mlwidth(*1.5) msymbol(O) mcolor("239 165 100")) 						/*
	*/ (scatter weeksfullyclosed  gee  if Geographicalregion == "Middle East and North Africa", 	/*
	*/ 				mlwidth(*1.5) msymbol(O) mcolor("236 110 109")) 						/*
	*/ (scatter weeksfullyclosed  gee  if Geographicalregion == "South Asia", 				/*
	*/ 				mlwidth(*1.5) msymbol(O) mcolor("248 203 202")) 						/*
	*/ (scatter weeksfullyclosed  gee  if Geographicalregion == "Sub-Saharan Africa", 		/*
	*/ 				mlwidth(*1.5) msymbol(O) mcolor("115 49 39")) 				/*
	*/ (scatter weeksfullyclosed  gee  if marker == 1  , 						/*
	*/ 				msymbol(Oh) mcolor(black) mlabcolor(black) mlabel(country) 	/*
	*/ 				mlabposition(3) mlabsize(*1.6) mlwidth(*1)) 				/*
	*/ 	if  IncomegroupWorldBanklistof != "High Income", 						/*
	*/  	xlab(-3(1)3, angle(0)   nogrid labsize(medium) 						/*
	*/ 		labcolor("202 182 163")) ylab(0(15)75 ,nogrid labsize(medium) 		/*
	*/ 		labcolor("202 182 163"))											/*
	*/ 		legend(order(1 "East Asia and Pacific" 2 "Europe and Central Asia" 	/*
	*/ 		3 "Latin America and the Caribbean" 4 "Middle East and North Africa" /*
	*/ 		5  "South Asia" 6 "Sub-Saharan Africa" ) 							/*
	*/ 	region(lcolor(none)) rows(4) pos(6) size(medsmall)) 					/*
	*/   	ytitle("Lenght of full school closures (weeks)", 					/*
	*/ 		size(medium) color("202 182 163"))									/*
	*/ 		xscale(lcolor("202 182 163") lwidth(*1.2) ) 						/*
	*/ yscale(lcolor("202 182 163") lwidth(*1.2) ) 								/*
	*/  	xtitle("Goverment effectiveness", size(medium) /*
	*/ color("202 182 163"))	xsize(6) ysize(5)

	gr export "${out_ch3}/Ch3_Fig3Box_1PanelB_GovEffectiveness_v_School_Closures.wmf", replace 	
		
		
	gen marker2 =1 if country == "Uruguay" | country == "Mexico" | 				/*
	*/ country == "Turkey"  | country == "Croatia" | country == "Tunisia" | 	/*
	*/  country == "Iraq"  |  country == "Bangladesh" |  country == "Bhutan" |  /*
	*/ country == "Burkina Faso" |  country == "Sri Lanka" | country == "Rwanda"
	
	replace country = "Türkiye" if country == "Turkey" 

	twoway 	(scatter weeksfullyclosed  log_gdp19  if Geographicalregion == "East Asia and Pacific", 	/*
	*/ 						mlwidth(*1.5) msymbol(O) mcolor("26 161 187" )) 	/*
	*/ 		(scatter weeksfullyclosed  log_gdp19  if Geographicalregion == "Europe and Central Asia", 	/*
	*/ 						mlwidth(*1.5) msymbol(O) mcolor("101 188 160")) 	/*
	*/ 		(scatter weeksfullyclosed  log_gdp19  if Geographicalregion == "Latin America and the Caribbean", 	/*
	*/ 						mlwidth(*1.5) msymbol(O) mcolor("239 165 100")) 	/*
	*/ 		(scatter weeksfullyclosed  log_gdp19  if Geographicalregion == "Middle East and North Africa", 		/*
	*/ 						mlwidth(*1.5) msymbol(O) mcolor("236 110 109")) 	/*
	*/ 		(scatter weeksfullyclosed  log_gdp19  if Geographicalregion == "South Asia", 				/*
	*/ 						mlwidth(*1.5) msymbol(O) mcolor("248 203 202")) 	/*
	*/ 		(scatter weeksfullyclosed  log_gdp19  if Geographicalregion == "Sub-Saharan Africa", 		/*
	*/ 						mlwidth(*1.5) msymbol(O) mcolor("115 49 39")) 		/*
	*/ 		(scatter weeksfullyclosed  log_gdp19  if marker2 == 1 , 			/*
	*/ 						msymbol(Oh) mcolor(black) mlabcolor(black) mlabel(country) /*
	*/ 						mlabposition(3) mlabsize(*1.6) mlwidth(*1)) 		/*
	*/		if  IncomegroupWorldBanklistof != "High Income", 					/*
	*/ 		 xlab(6(2)12, angle(0)   nogrid labsize(medium) 					/*
	*/ 		labcolor("202 182 163")) ylab(0(15)75 ,nogrid labsize(medium)  		/*
	*/ 		labcolor("202 182 163"))											/*
	*/ 		legend(order(1 "East Asia and Pacific" 2 "Europe and Central Asia" 	/*
	*/ 		3 "Latin America and the Caribbean" 4 "Middle East and North Africa" /*
	*/ 		5 "South Asia" 6 "Sub-Saharan Africa" ) 							/*
	*/ 		region(lcolor(none)) rows(4) pos(6) size(medsmall)) 				/*
	*/ 		ytitle("Lenght of full school closures (weeks)", size(medium) 		/*
	*/ 		color("202 182 163"))												/*
	*/ 		xscale(lcolor("202 182 163") lwidth(*1.2) ) 						/*
	*/ 		yscale(lcolor("202 182 163") lwidth(*1.2) ) 						/*
	*/ 		xtitle("GDP per capita (logs)", size(medium) color("202 182 163")) /*
	*/ 		xsize(6) ysize(5)
			

		gr export "${out_ch3}/Ch3_Fig3Box_1PanelA_GDPpercapita_v_School_Closures.wmf", replace 	
		
	