********************************************************************************
* By: Ritika DSouza
*  Table 3.A1
*******************************************************************************
cap ssc install keeporder

* Load data
	use "$dt_Other/Raw/Lost LAYS for rep.dta", replace /*Un anonymized data required. Not shared*/


// Generate appendix table for Nigeria
keep if wbcode=="NGA"
// Keep needed vars
keeporder wbcode schcl qual ///
sz_h2_gr1_pp sz_h2_gr2_pp sz_h2_gr3_pp ///
sz_h2_gr1_p sz_h2_gr2_p sz_h2_gr3_p ///
sz_h2_gr1_ls sz_h2_gr2_ls sz_h2_gr3_ls ///
sz_h2_gr1_us sz_h2_gr2_us sz_h2_gr3_us ///
ls_h2_gr1_pp ls_h2_gr1_p ls_h2_gr1_ls ls_h2_gr1_us  ///
ls_h2_gr2_pp ls1_h2_gr2_p ls2_h2_gr2_p ///
ls1_h2_gr2_ls ls2_h2_gr2_ls ls_h2_gr2_us ///
ls_h2_gr3_pp ls_h2_gr3_p ls_h2_gr3_ls ls_h2_gr3_us  ///
ll_h2_gr1_pp ll_h2_gr2_pp ll_h2_gr3_pp ///
ll_h2_gr1_p ll_h2_gr2_p ll_h2_gr3_p ///
ll_h2_gr1_ls ll_h2_gr2_ls ll_h2_gr3_ls /// 
ll_h2_gr1_us ll_h2_gr2_us ll_h2_gr3_us ///
ll_h2_tot_pp ll_h2_tot_p ll_h2_tot_ls ll_h2_tot_us ll_h2_tot

rename *_h2_* *_* 

gen ls_gr2_p= (ls1_gr2_p+ls2_gr2_p)/2
gen ls_gr2_ls= (ls1_gr2_ls+ls2_gr2_ls)/2
drop ls1* ls2*

// Reshape data
reshape long sz_gr1_ sz_gr2_ sz_gr3_ ///
	ls_gr1_ ls_gr2_ ls_gr3_ ///
	ll_gr1_ ll_gr2_ ll_gr3_ ///
	ll_tot_, i(wbcode) j(level) s
	
rename ll_tot ll_tot_a

// Generate school levels
gen schlev=.
	replace schlev=1 if level=="pp" // Pre-primary
	replace schlev=2 if level=="p" // Primary
	replace schlev=3 if level=="ls" // Lower secondary
	replace schlev=4 if level=="us" // Upper secondary
	
insobs 1	// Add a line for average LAYS lost
replace schlev=5 if schlev==.

// Label school levels
la def schlev 1 "Pre-primary" 2 "Primary" 3 "Lower secondary" 4 "Upper secondary" 5 "Average LAYS lost", modify
la val schlev schlev
sort schlev
la var schlev "School level"

// Change avg total LAYS lost to positive for table
replace ll_tot_=ll_tot_a[_n-1] if ll_tot_==. 
replace ll_tot_= ll_tot_*-1 if schlev==5

drop level ll_tot_a
rename *_ *

// Generate durations for different school levels
gen dur=.
replace dur=2 if schlev==1
replace dur=6 if schlev==2
replace dur=3 if inrange(schlev,3,4)
la var dur "Duration of level (years)"

// Label vars
la var schcl "Duration of school closure (years)"
la var qual "Quality adjustment factor"

forvalues x=1/3 {
	la var sz_gr`x' "Group Size Gr `x'"
}

forvalues x=1/3 {
	la var ls_gr`x' "Lost learning (years) Gr `x'"
}

forvalues x=1/3 {
	la var ll_gr`x' "Lost LAYS (years) Gr `x'"
}

la var ll_tot "Total lost LAYS"

// Outsheet table to Excel
keeporder schlev dur schcl qual sz_gr1 sz_gr2 sz_gr3 ls_gr1 ls_gr2 ls_gr3 ll_gr1 ll_gr2 ll_gr3 ll_tot
export excel using "${out_ch3}/Table 3A.1.xlsx", first(varl)

