*---------------------------------------------------------------------
* Margarita Isaacs
* EMPLOYMENT AND ENROLLMENT 
* In text numbers calculations
*---------------------------------------------------------------------

* In text numbers Chapter 4: 

*--------
* pg 105 
*--------

/* Between the fourth quarter of 2019 and the second quarter of 2020, 
191 million full-time jobs were lost in middle-income countries and 
25 million in high-income countries */

use "$dt_ch4/employment_world.dta", clear

gen year = substr(DATEQ,1,4)
gen quarter = substr(DATEQ,6,1)
destring year quarter, replace
gen dateq = yq(year, quarter)
format dateq %tq

* Create middle income and high income categories
gen inc_code = "_mi" if inlist(INC, "Upper Middle Income", "Lower Middle Income")
replace inc_code = "_hi" if INC == "High Income"  
drop if inc_code == ""

* Collapse data
rename EMPLOYMENT emp
collapse (sum) emp if non_miss_emp >= 7, by(inc_code dateq)
reshape wide emp, i(dateq) j(inc_code) string

* Calculate changes wrt. 2019q4
tset dateq, quarterly
global vars "emp_hi emp_mi"
foreach v of global vars {
	gen `v'_2019_aux = `v' if dateq == tq(2019q4)
	egen `v'_2019 = mode(`v'_2019_aux)
	gen ch_`v' = `v' - `v'_2019
	drop `v'_2019_aux `v'_2019 `v'
} 

* Show employment change in 2020q2 wrt. 2019q4 (data in thousands)
tabstat ch_emp_mi if dateq == tq(2020q2)  // middle income: 190 million approx.
tabstat ch_emp_hi if dateq == tq(2020q2)  // middle income: 25 million approx.


/* Overall, in the third quarter of 2021 about 40 million fewer people 
were employed in middle-income countries than before the pandemic */

* Show employment change in 2021q3 wrt. 2019q4 (data in thousands)
tabstat ch_emp_mi if dateq == tq(2021q3)  // middle income: 40 million approx.


/* In the second quarter of 2020, employment losses were 8 percentage points in 
lower-middle-income countries, compared with 2.6 percentage points in 
upper-middle-income countries and 4.3 percentage points in high-income countries. */ 

use "$dt_ch4/employment_world.dta", clear  

gen year = substr(DATEQ,1,4)
gen quarter = substr(DATEQ,6,1)
destring year quarter, replace
gen dateq = yq(year, quarter)
format dateq %tq

drop if INC == ""
keep if dateq >= tq(2012q1) & dateq <= tq(2021q3)

gen inc_code = "_li" if INC == "Low Income"  
replace inc_code = "_lmi" if INC == "Lower Middle Income"  
replace inc_code = "_umi" if INC == "Upper Middle Income"  
replace inc_code = "_hi" if INC == "High Income"  
drop INC

*Calculate weighted average by income group
collapse (mean) emp_rate if non_miss_emp >= 7 [iw = LP], by(inc_code dateq)
reshape wide emp_rate, i(dateq) j(inc_code) string

*Percentage point changes vis a vis 2019Q4
tset dateq, quarterly
global vars "emp_rate_hi emp_rate_li emp_rate_lmi emp_rate_umi"
foreach v of global vars {
	gen `v'_2019_aux = `v' if dateq == tq(2019q4)
	egen `v'_2019 = mode(`v'_2019_aux)
	gen pp_`v' = 100*(`v' - `v'_2019)  // Percentage point change
	drop `v'_2019_aux `v'_2019
}

*Show employment losses (percentage points) by income group in 2020q2
tabstat pp_emp_rate_lmi if dateq == tq(2020q2) // Lower middle income: 8 p.p.
tabstat pp_emp_rate_umi if dateq == tq(2020q2) // Upper middle income: 2.6 p.p.
tabstat pp_emp_rate_hi if dateq == tq(2020q2)  // High income: 4.3 p.p.

/* Even though the recovery in employment was almost complete by the third quarter 
of 2021 in high- and upper-middle-income countries, it was still 3.5 percentage 
points below pre-pandemic levels in lower-middle-income countries */

*Show employment losses (percentage points) by income group in 2021q3
tabstat pp_emp_rate_lmi if dateq == tq(2021q3)  // Lower middle income: 3.5 p.p.
tabstat pp_emp_rate_umi if dateq == tq(2021q3)  // Upper middle income: 0.7 p.p.
tabstat pp_emp_rate_hi if dateq == tq(2021q3)   // High income: 0.4 p.p.

*--------
* pg 105 
*--------

use "$dt_ch4/Labor Predictions.dta", replace 

label define dat 241 "2020:Q2" 242 "2020:Q3" 243 "2020:Q4" 244 "2021:Q1" 245 "2021:Q2"  246 "2021:Q3"  247 "2021:Q4" 
label values dateq dat

/* These declines were particularly pronounced in the Philippines (with a decline of 11 percentage points), in Türkiye (with a decline of
7 percentage points), and in the two Latin American countries in the sample (with a 6 percentage point decline in Brazil and an 8 percentage point decline in Mexico). On the other hand, youth employment increased in the two lower-income countries in the sample—by 1 percentage point in Ethiopia and by 3 percentage points in Pakistan.*/

replace dateq = yq(2020,2) if dateq == yq(2020,3) & country == "Pakistan"
tabstat pp_empr_yo if dateq==yq(2020,2) & (country == "Philippines" | country == "Turkiye" | country == "Brazil" | country == "Mexico" | country == "Pakistan" ) | (year == 2021  & country== "Ethiopia") , by(country) format(%12.0fc)

*--------
* Pg 108 
*--------

/*However, India is an important exception: the reduction in wages (−40 percent in the second quarter of 2020 and −22 percent in the first quarter of 2021) was even larger than the reduction in youth employment in this period (−29 percent in the second quarter of 2020 and −6 percent in the first quarter of 2021)*/

tabstat p_d_wage_yo  p_d_empr_yo if (dateq==yq(2020,2) | dateq==yq(2021,1) ) & (country == "India" ) , by(dateq) format(%12.0fc)

/*
Specifically, the number of hours worked by employed young people fell—by six hours a week in Brazil, nine hours a week in South Africa, and 20 hours a week in the Philippines (from 39 to 19)
*/

*br hrswrk_yo dateq country if (country == "Brazil"  | country == "SouthAfrica" |country == "Philippines" )  & ( dateq==yq(2019,4) |dateq==yq(2020,2) 

*--------
* Pg 109 
*--------

/**Figure 4.4 contains some important results about the six countries of interest here. First, in one (Paistan) there was a large decline in school enrollment (−7 percentage points in the first quarter of 2021), whereas in another (Vietnam), there was a large increase (+7 percentage points in the fourth quarter of 2021). */ 

tabstat pp_enrollr_yo if (dateq==yq(2021,1) & country == "Pakistan") | (country == "Vietnam"  & dateq==yq(2021,4) ), by(country) format(%12.0fc)

/*Second, differences by gender are generally modest—with the exception of Pakistan, where the decline in school enrollment was substantially larger among young men (−9 percentage points) thanamong young women (−5 percentage points)*/

tabstat pp_enrollr_f_yo pp_enrollr_m_yo if (dateq==yq(2020,2) & country == "Pakistan") , by(country) format(%12.0fc)

*--------
*Pg 110 
*--------

/*On average, in the six countries for which data are available, NEETs now represent 24 percent of all young people.*/

tabstat neetr_yo if year == 2021 & (country == "Brazil" | country == "Ethiopia" | country == "Mexico" |  country == "Pakistan"  | country == "SouthAfrica" |country == "Vietnam" ), 

/*The figure shows that in South Africa, the share of NEETs in the fourth quarter of 2021 was 9 percentage points higher than it would have been in the absence of the pandemic, while in Vietnam it was 8 percentage points higher*/ 

tabstat pp_d_neetr_yo if dateq == yq(2021,4) & (country == "SouthAfrica" ), format(%12.0fc)

*--------
* Pg 124 
*--------

/*
The bars in panel b show that because youth employment in the Philippines generally spikes in the second quarter of the year, estimates that do not account for seasonal effects underestimate employment losses in the second quarter of 2020 (a decline of 31 percent in the naïve estimate, compared with a decline of33 percent in the preferred estimate). On the other hand, because of the sharp downward trend in youth
employment in the Philippines, estimates that do not take into account the trend overestimate the effects of the pandemic on youth employment in the second quarter of 2021 (a decline of 14 percent in the naïve estimate, compared with a decline of 9 percent in the preferred estimate)

*/
keep if country == "Philippines"

* Wrt 2019q4
gen aux_empr_yo_2019q4 = empr_yo if dateq == yq(2019,4)
egen empr_yo_2019q4 = max(aux_empr_yo_2019q4)
gen impact_2019q4 = (empr_yo-empr_yo_2019q4)*100/empr_yo_2019q4
label var impact_2019q4 "Impact wrt 2019q4"

*Only trend 
reg log_empr_yo trend   if dateq <= yq(2019,4)
predict trend_empr_yo, xb 
gen y_hat_trend_empr_yo = exp(trend_empr_yo) 

* Seasonal adjutment and trend 
reg log_empr_yo    quarter_1 quarter_2 quarter_3 quarter_4  if dateq <= yq(2019,4)
predict quarter_empr_yo, xb 
gen y_hat_quarter_empr_yo =exp(quarter_empr_yo)	
	
* Percentage changes 
gen p_trend_empr_yo = (empr_yo- y_hat_trend_empr_yo) *100/y_hat_trend_empr_yo
gen p_quarter_empr_yo = (empr_yo- y_hat_quarter_empr_yo) *100/y_hat_quarter_empr_yo
gen p_2019q4_empr_yo = (empr_yo- empr_yo_2019q4) *100/empr_yo_2019q		
			
gen pp_trend_empr_yo = (empr_yo- y_hat_trend_empr_yo) 
gen pp_quarter_empr_yo = (empr_yo- y_hat_quarter_empr_yo) 
gen pp_2019q4_empr_yo = (empr_yo- empr_yo_2019q4)



tabstat p_2019q4_empr_yo p_trend_empr_yo   p_d_empr_yo if dateq == yq(2020,2) | dateq == yq(2021,1), format(%12.0fc) by(dateq)



