********************************************************************************
* By: Margarita Isaacs 
*  Figure 4.2 
*******************************************************************************




* Load the dataset
use "$dt_ch4/Labor Predictions.dta", replace

* Keep only the observations for specific countries
keep if country == "Brazil" | country == "India" | country == "Mexico" | country == "Philippines" | country == "Vietnam" | country == "SouthAfrica"

* Replace the value of "dateq" for India
replace dateq = yq(2021,4) if dateq == yq(2021,3) & country == "India"

* Calculate the summary statistics for "p_wage_yo" in South Africa for Q4 2020
sum p_wage_yo if dateq == yq(2020,4) & country == "SouthAfrica"

* Replace missing values in "p_wage_yo" with the calculated mean for Q1 2021 in South Africa
replace p_wage_yo = `r(mean)' if dateq == yq(2021,1) & country == "SouthAfrica"

* Define value labels for "dateq" variable
label define dat 241 "2020:Q2"  242 "2020:Q3" 244 "2021:Q1" 246 "2021:Q3"  247 "2021:Q4" 
label values dateq dat

* Create a grouped bar graph for "p_empr_yo" and "p_wage_yo" by dateq and country
graph bar p_empr_yo p_wage_yo  ///
    if (dateq == yq(2020,2) | dateq == yq(2021,1) | dateq == yq(2021,4)) ///
    , over(dateq, label(angle(90) labsize(large))) over(country, label(labsize(large))) ///
    bar(1, color(${cemerald}))  bar(2, color(${cgreen})) ///
    ylab(-45(15)30, labsize(medium) nogrid) ///
    graphregion(color(white) margin(vsmall)) ///
    ytitle("Percentage change", size(medium))  ///
    blabel(total, format(%12.0fc) size(medsmall)) /// 
    legend(order(1  "Youth employment" 2 "Youth wages ") ///
    region(lcolor(white) margin(medium))  symxsize(*.5) ///
    pos(6) size(medium) rows(1)) xsize(7) ysize(3) 

* Export the graph as a Windows Metafile (WMF) format
gr export "${out_ch4}/Ch4_Fig4_3_Employment_vs_wages_forYouth.wmf", replace
