
*---------------------------------------------------------------------
* BOX ON METHODOLOGY
* Author Margarita Isaacs 
*---------------------------------------------------------------------
global legend_options "region(lcolor(white) margin(medium))  symxsize(*.8) pos(6) size(medium) rows(1)"
global graph_options "graphregion(color(white) margin(vsmall)) xsize(4) ysize(3) "
		
	
use "$dt_ch4/Labor Predictions.dta", replace 
keep if country == "Philippines"


label define dat 241 "2020:Q2" 242 "2020:Q3" 243 "2020:Q4" 244 "2021:Q1" 245 "2021:Q2"  246 "2021:Q3"  247 "2021:Q4" 
label values dateq dat

* Wrt 2019q4
gen aux_empr_yo_2019q4 = empr_yo if dateq == yq(2019,4)
egen empr_yo_2019q4 = max(aux_empr_yo_2019q4)
gen impact_2019q4 = (empr_yo-empr_yo_2019q4)*100/empr_yo_2019q4
label var impact_2019q4 "Impact wrt 2019q4"

*Only trend 
reg log_empr_yo trend   if dateq <= yq(2019,4)
predict trend_empr_yo, xb 
gen y_hat_trend_empr_yo = exp(trend_empr_yo) 

* Seasonal adjutment and trend 
reg log_empr_yo    quarter_1 quarter_2 quarter_3 quarter_4  if dateq <= yq(2019,4)
predict quarter_empr_yo, xb 
gen y_hat_quarter_empr_yo =exp(quarter_empr_yo)	
	
* Percentage changes 
gen p_trend_empr_yo = (empr_yo- y_hat_trend_empr_yo) *100/y_hat_trend_empr_yo
gen p_quarter_empr_yo = (empr_yo- y_hat_quarter_empr_yo) *100/y_hat_quarter_empr_yo
gen p_2019q4_empr_yo = (empr_yo- empr_yo_2019q4) *100/empr_yo_2019q4		
			
gen pp_trend_empr_yo = (empr_yo- y_hat_trend_empr_yo) 
gen pp_quarter_empr_yo = (empr_yo- y_hat_quarter_empr_yo) 
gen pp_2019q4_empr_yo = (empr_yo- empr_yo_2019q4)
			

tw  (line empr_yo dateq, lp(solid) lc("115 49 39") lw(*1)) 					 /*
*/	(line y_hat_trend_empr_yo dateq, lp(dash) lc("182 145 108") lw(*1.5))  	 /*
*/	(line y_hat_quarter_empr_yo dateq, lp(shortdash) lc("26 161 187") lw(*1.5))  /*
*/	(line y_hat_empr_yo dateq, lp(solid) lc("101 188 160") lw(*1.5)) , 		 /*
*/	legend(pos(6) rows(3) order(1 "Observed Employment" 					 /*
*/	2 "Trend" 3 "Seasonal Effect" 4 "Predicted Employment") 				 /*
*/	size(medium) symxsize(medium) ) 										 /*
*/	xline( `=yq(2020, 1)', lcolor("239 165 100") lwidth(*1)) 				 /*
*/	ytitle("Employment rate (percent)", size(medium)) xtitle("")			 /*
*/	xlabel(`=yq(2011, 2)' "2011: Q2" `=yq(2013, 2)'  						 /*
*/ "2013: Q2" `=yq(2015, 2)' "2015: Q2" `=yq(2017, 2)' 						 /*
*/ "2017: Q2" `=yq(2019, 2)' "2019: Q2" `=yq(2021, 2)' 						 /*
*/ "2021: Q2", labsize(medium) nogrid angle(90)) 							 /*
*/ ylab(20(5)40, nogrid labsize(medium))									 /*
*/ title("a. Philippines,"" 2011:Q2–2021:Q2", size(vlarge) ) 				 /*
*/	$graph_options
	

gr export "${out_ch4}//Ch4_FigAnnexx4_1_PanelA_Methodology_Timeseries.wmf", replace 

 
 
graph bar p_2019q4_empr_yo p_trend_empr_yo   p_d_empr_yo					 /*
*/ if   dateq > yq(2020,1) , over(dateq, label(labsize(medium)) )			 /*
*/ ylab( -40(15)20, labsize(large) nogrid)									 /*
*/ blabel(total, format(%12.0fc) size(medsmall))							 /*
*/ bar(1, color("182 145 108"))												 /*
*/ bar(2, color("26 161 187"))  											 /*
*/ bar(3, color("101 188 160"))												 /*
*/ ytitle(Percentage change, size(medium)) 									 /*
*/ legend(order(1  "Scenario 1" 2 "Scenario 2"  3 "Scenario 3")				 /*
*/ $legend_options ) title("b. Philippines, ""2020:Q2–2021:Q2", size(vlarge)) /*
*/	$graph_options
 
gr export "${out_ch4}//Ch4_FigAnnex4_1_PanelB_Methodology_Bars.wmf", replace 
